from django import template
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe
from django.utils.html import conditional_escape
from licenses.models import License

register = template.Library()


class GetLicenseNode(template.Node):
    '''
        Generic node to get one license, the tag defines the search paramter.
    '''

    #@classmethod
    def handle_token(cls, parser, token, field):
        tokens = token.split_contents()
        if len(tokens) == 4:
            if tokens[2] != 'as':
                raise template.TemplateSyntaxError("Second argument in %s must be 'as'" % tokens[0])
            return cls(query=tokens[1], varname=tokens[3], field=field)
        else:
            raise template.TemplateSyntaxError("%r tag requires 3 arguments" % tokens[0])
    handle_token = classmethod(handle_token)

    def __init__(self, query=None, varname=None, field=None):
        self.varname = varname
        self.lookup = lookup
        self.field = field

    def render(self, context):
        try:
            lookup_dict = {self.field: self.query}
            license = License.objects.filter(**lookup_dict)[0]
        except IndexError:
            license = None
        context[self.varname] = license
        return ''


#@register.tag
def get_license_by_abbr(parser, token):
    '''
        Usage: {% get_license_by_abbr "short_name" as varname %}
    '''
    return GetLicenseNode.handle_token(parser, token, field='abbreviation')
get_license_by_abbr = register.tag(get_license_by_abbr)

#@register.tag
def get_license_by_slug(parser, token):
    '''
        Usage: {% get_license_by_slug "slug" as varname %}
    '''
    return GetLicenseNode.handle_token(parser, token, field='slug')
get_license_by_slug = register.tag(get_license_by_slug)

#@register.filter
def license_link(license):
    '''
        Usage {{ license|license_link }}
    '''
    return render_to_string('licenses/link.html', {
        'name': conditional_escape(license.name),
        'url': conditional_escape(license.url),
    })
register.filter(license_link)

#@register.filter
def license_logo(license):
    '''
        Usage {{ license|license_logo }}
    '''
    return render_to_string('licenses/logo.html', {
        'name': conditional_escape(license.name),
        'url': conditional_escape(license.url),
        'img': conditional_escape(license.logo),
    })
register.filter(license_logo)
